
RSpec.describe "EitilCore Date#strfsql(type)" do

  let(:date) { Date.parse('01-01-2020').strfsql(@type) }

  it "should by default format a Date instance to '%Y-%m-%d'" do   
    date = Date.parse('01-01-2020').strfsql 
    expect(date).to eq '2020-01-01'
  end

  it "should format a Date instance to '%Y-%m-%d', if :date is given as type" do   
    @type = :date
    expect(date).to eq '2020-01-01'
  end

  it "should simply return nil if an invalid type is given" do
    @type = 666
    expect(date).to be_nil
  end

end


RSpec.describe "EitilCore DateTime#strfsql(type)" do

  let(:datetime) { DateTime.parse('01-01-2020').strfsql(@type) }

  it "should by default format a DateTime instance to '%Y-%m-%d %H:%M:%S.%6N'" do   
    datetime = DateTime.parse('01-01-2020').strfsql
    expect(datetime).to eq "2020-01-01 00:00:00.000000"
  end

  it "should format a DateTime instance to '%Y-%m-%d %H:%M:%S.%6N', if :datetime is given as type" do   
    @type = :datetime
    expect(datetime).to eq "2020-01-01 00:00:00.000000"
  end


  it "should format a DateTime instance to '%Y-%m-%d', if :date is given as type" do   
    @type = :date
    expect(datetime).to eq "2020-01-01"
  end


  it "should format a DateTime instance to '%H:%M:%S', if :time is given as type" do   
    @type = :time
    expect(datetime).to eq "00:00:00"
  end

  it "should simply return nil if an invalid type is given" do
    @type = 666
    expect(datetime).to be_nil
  end

end



RSpec.describe "EitilCore Time#strfsql(type)" do

  let(:time) { Time.parse('01-01-2020 20:00:00 +0200').strfsql(@type) }

  it "should by default format a Time instance to '%Y-%m-%d %H:%M:%S.%6N'" do   
    time = Time.parse('01-01-2020 20:00:00 +0200').strfsql
    expect(time).to eq "20:00:00"
  end

  it "should format a Time instance to '%Y-%m-%d %H:%M:%S.%6N', if :datetime is given as type" do   
    @type = :datetime
    expect(time).to eq "2020-01-01 20:00:00.000000"
  end


  it "should format a Time instance to '%Y-%m-%d', if :date is given as type" do   
    @type = :date
    expect(time).to eq "2020-01-01"
  end


  it "should format a Time instance to '%H:%M:%S', if :time is given as type" do   
    @type = :time
    expect(time).to eq "20:00:00"
  end

  it "should simply return nil if an invalid type is given" do
    @type = 666
    expect(time).to be_nil
  end

end