
RSpec.describe "EitilCore #is_num? and #is_nan?" do

  context "for String" do

    it "#is_num? should return true for '5' (integers)" do 
      expect('5'.is_num?).to be_truthy
    end

    it "#is_num? should return true for '5.0' (floats) " do 
      expect('5.0'.is_num?).to be_truthy
    end

    it "#is_num? should return true for '5,0' (floats, separated by comma) " do 
      expect('5,0'.is_num?).to be_truthy
    end

    it "#is_num? should return false for valid values, '5a' (concatenated with additional letters)" do 
      expect('5a'.is_num?).to   be_falsy
      expect('5.0a'.is_num?).to be_falsy
      expect('5,0a'.is_num?).to be_falsy
    end

    it "#is_nan? should return the opposite" do 
      expect('5'.is_nan?).to be_falsy
      expect('5.0'.is_nan?).to be_falsy
      expect('5,0'.is_nan?).to be_falsy
      expect('5a'.is_nan?).to   be_truthy
      expect('5.0a'.is_nan?).to be_truthy
      expect('5,0a'.is_nan?).to be_truthy
    end

  end

  context "for Numeric" do

    it "#is_num? should always return true" do
      expect(1.is_num?).to   be_truthy
      expect(1.0.is_num?).to be_truthy
    end

    it "#is_nan? should always return false" do
      expect(1.is_nan?).to   be_falsy
      expect(1.0.is_nan?).to be_falsy
    end

  end

  context "for NilClass" do

    it "#is_num? should always return false" do
      expect(nil.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(nil.is_nan?).to be_truthy
    end

  end

  context "for TrueClass" do

    it "#is_num? should always return false" do
      expect(true.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(true.is_nan?).to be_truthy
    end

  end

  context "for FalseClass" do

    it "#is_num? should always return false" do
      expect(false.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(false.is_nan?).to be_truthy
    end

  end

  context "for Hash" do

    it "#is_num? should always return false" do
      expect({}.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect({}.is_nan?).to be_truthy
    end

  end

  context "for Array" do

    it "#is_num? should always return false" do
      expect([].is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect([].is_nan?).to be_truthy
    end

  end

  context "for Date" do

    it "#is_num? should always return false" do
      expect(Date.today.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(Date.today.is_nan?).to be_truthy
    end

  end

  context "for Time" do

    it "#is_num? should always return false" do
      expect(Time.now.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(Time.now.is_nan?).to be_truthy
    end

  end

  context "for DateTime" do

    it "#is_num? should always return false" do
      expect(DateTime.now.is_num?).to be_falsy
    end

    it "#is_nan? should always return true" do
      expect(DateTime.now.is_nan?).to be_truthy
    end

  end

end

